/*
 *  This sketch demonstrates how to set up a simple HTTP-like server.
 *  Para instalar ESP8266 en el IDE http://arduino.esp8266.com/stable/package_esp8266com_index.json 
 *  The server will set a GPIO pin depending on the request
 *    http://server_ip/gpio/0 will set the GPIO2 low,
 *    http://server_ip/gpio/1 will set the GPIO2 high
 *  server_ip is the IP address of the ESP8266 module, will be 
 *  printed to Serial when the module is connected.
 *  
 *  These pins are general purpose and can be used for any sort of input or 
 *  output. Most also have the ability to turn on an internal pullup. The 
 *  only 'strange' pin is GPIO #0, which does not have an internal pullup, 
 *  and is also connected to both a mini tactile switch and red LED. This 
 *  pin is used by the ESP8266 to determine when to boot into the bootloader.
 *
 * For this reason, we dont recommend connecting anything to GPIO #0, because 
 * if the pin is held low during power-up it will start bootloading! That 
 * said, you can use it as an output, and blink the red LED.
 * 
 * https://learn.adafruit.com/esp8266-temperature-slash-humidity-webserver 
 * 
 * ESP8266 GPIO can provide max of 12mA
 * 
 * http://www.whatimade.today/esp8266-and-the-water-heater/ 
 * 
 */

#include <ESP8266WiFi.h>

const char* ssid = "ULPGC";
const char* password = "";

// Create an instance of the server
// specify the port to listen on as an argument
WiFiServer server(80);

void setup() {
  Serial.begin(115200);
  delay(10);

  // prepare GPIO2
  pinMode(2, OUTPUT);
  digitalWrite(2, 0);
  
  // Connect to WiFi network
  Serial.println();
  Serial.println();
  Serial.print("Connecting to ");
  Serial.println(ssid);

  //Conecta a redes abiertas
  if (password != "")
    WiFi.begin(ssid, password);
  else
    WiFi.begin(ssid, password);
  
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.println("WiFi connected");
  
  // Start the server
  server.begin();
  Serial.println("Server started");

  // Print the IP address
  Serial.println(WiFi.localIP());
}

void loop() {
  // Check if a client has connected
  WiFiClient client = server.available();
  if (!client) {
    return;
  }
  
  // Wait until the client sends some data
  Serial.println("new client");
  while(!client.available()){
    delay(1);
  }
  
  // Read the first line of the request
  String req = client.readStringUntil('\r');
  Serial.println(req);
  client.flush();
  
  // Match the request
  int val = -1;
  long rssi = -1;
  
  if (req.indexOf("/gpio/0") != -1)
    val = 0;
  else if (req.indexOf("/gpio/1") != -1)
    val = 1;
  else if (req.indexOf("/rssi") != -1)
    //Prepara la respuesta para informar de la potencia recibida
    rssi = WiFi.RSSI();
  else {
    Serial.println("invalid request");
    client.stop();
    return;
  }

  // Set GPIO2 according to the request
  digitalWrite(2, val);
  
  client.flush();

  // Prepare the response
  String s = "HTTP/1.1 200 OK\r\nContent-Type: text/html\r\n\r\n<!DOCTYPE HTML>\r\n<html>\r\n";
  if (val > -1) {
    //Respuesta para el estado de las patillas
    s += "GPIO is now ";
    s += (val)?"high":"low";
  }
  if (rssi >-1) {
    //Respuesta para la potencia
    s += "RSSI = ";
    s += (rssi)?"high":"low";   //Hay que poner el valor de la potencia
  }
  s += "</html>\n";

  // Send the response to the client
  client.print(s);
  delay(1);
  Serial.println("Client disonnected");

  // The client will actually be disconnected 
  // when the function returns and 'client' object is detroyed
}

